@@ -1,4 +1,4 @@
-eqtlDir.P <- function(genoGroups,gex,mc=mc){
+eqtlDir.P <- function(genoGroups,gex,mc=mc,nper){
 
   output <- c()
     innerFunction <- function(i)
@@ -11,12 +11,12 @@ eqtlDir.P <- function(genoGroups,gex,mc=mc){
 	
 	# Then the 2 groups comparison
 	} else if (PI==2){
-	  output[i] <- gmw(gex[!is.na(genoGroups[,i])],genoGroups[!is.na(genoGroups[,i]),i],test="mw",type="permut",alternative="two.sided")
+	  output[i] <- gmw(gex[!is.na(genoGroups[,i])],genoGroups[!is.na(genoGroups[,i]),i],test="mw",type="permut",alternative="two.sided",nper=nper)
 
 	# And the three group comparison
 	} else if (PI==3){
-	  p1 <- gmw(gex[!is.na(genoGroups[,i])],genoGroups[!is.na(genoGroups[,i]),i],test="triple",type="permutation",alternative="greater",alg="Csub")
-	  p2 <- gmw(gex[!is.na(genoGroups[,i])],createGroups(genoGroups[!is.na(genoGroups[,i]),i],c(2,1,0)),test="triple",type="permutation",alternative="greater",alg="Csub")
+	  p1 <- gmw(gex[!is.na(genoGroups[,i])],genoGroups[!is.na(genoGroups[,i]),i],test="triple",type="permutation",alternative="greater",alg="Csub",nper=2000)
+	  p2 <- gmw(gex[!is.na(genoGroups[,i])],createGroups(genoGroups[!is.na(genoGroups[,i]),i],c(2,1,0)),test="triple",type="permutation",alternative="greater",alg="Csub",nper=2000)
 	  output[i] <- min(2*min(p1,p2),1)
 	  
 	}
